/* $Id: isaac_img_darkron.c,v 1.3 2009/04/28 14:45:17 llundin Exp $
 *
 * This file is part of the DETMON Pipeline
 * Copyright (C) 2002,2003 European Southern Observatory
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 * $Author: llundin $
 * $Date: 2009/04/28 14:45:17 $
 * $Revision: 1.3 $
 * $Name: HEAD $
 */
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

/*----------------------------------------------------------------------------
                             Includes
 ----------------------------------------------------------------------------*/

#include <cpl.h>

#include "irplib_detmon.h"
#include "irplib_plugin.h"

#include "isaac_dfs.h"

#define RECIPE_NAME "isaac_img_darkron"

/*----------------------------------------------------------------------------
				Functions prototypes
 ----------------------------------------------------------------------------*/

CPL_RECIPE_DEFINE(isaac_img_darkron, ISAAC_BINARY_VERSION,
                  irplib_detmon_darkron_fill_parlist_default(
                                                           recipe->parameters,
                                                             RECIPE_NAME,
                                                             PACKAGE_TARNAME),
                  "Lars Lundin", PACKAGE_BUGREPORT, "2008", 
                  "Dark/RON recipe",
                  irplib_detmon_ronbias_get_description(RECIPE_NAME,
                                                        PACKAGE_TARNAME,
                                                        ISAAC_IMG_DARK_RAW));

/*---------------------------------------------------------------------------*/
/*
  @brief    Interpret the command line options and execute the data processing
  @param    frameset    the frames list
  @param    parlist     the parameters list
  @return   0 if everything is ok
 */
/*---------------------------------------------------------------------------*/

static int isaac_img_darkron(cpl_frameset            * frameset,
			     const cpl_parameterlist * parlist)
{
    cpl_propertylist * master = 
	irplib_detmon_fill_prolist("MASTER_BIAS", "TYPE", "TECH", CPL_TRUE);

    cpl_propertylist * synth = 
	irplib_detmon_fill_prolist("SYNTH",       "TYPE", "TECH", CPL_TRUE);

    cpl_propertylist * bpmhot = 
	irplib_detmon_fill_prolist("BP_MAP_HP",   "TYPE", "TECH", CPL_TRUE);

    cpl_propertylist * bpmcold = 
	irplib_detmon_fill_prolist("BP_MAP_CP",   "TYPE", "TECH", CPL_TRUE);

    cpl_propertylist * bpmdev = 
	irplib_detmon_fill_prolist("BP_MAP_DP",   "TYPE", "TECH", CPL_TRUE);

    const cpl_error_code error = 
	irplib_detmon_ronbias(frameset, parlist, ISAAC_IMG_DARK_RAW,
			      RECIPE_NAME, PACKAGE_TARNAME, REGEXP,
			      master, NULL, NULL, synth, 
			      bpmhot, bpmcold, bpmdev,
			      PACKAGE "/" PACKAGE_VERSION, NULL, NIR);

    cpl_propertylist_delete(master);
    cpl_propertylist_delete(synth);
    cpl_propertylist_delete(bpmhot);
    cpl_propertylist_delete(bpmcold);
    cpl_propertylist_delete(bpmdev);

    /* Propagate the error, if any */
    cpl_ensure_code(!error, error);

    return CPL_ERROR_NONE;
}
